==> php-nrk-predis_2.4.1.orig.tar.xz: php-nrk-predis-2.4.1/tests/Predis/Command/Redis/TopK/TOPKINCRBY_Test.php <==
<?php

/*
 * This file is part of the Predis package.
 *
 * (c) 2009-2020 Daniele Alessandri
 * (c) 2021-2025 Till Krüss
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Predis\Command\Redis\TopK;

use Predis\Command\Redis\PredisCommandTestCase;
use Predis\Response\ServerException;

/**
 * @group commands
 * @group realm-stack
 */
class TOPKINCRBY_Test extends PredisCommandTestCase
{
    /**
     * {@inheritDoc}
     */
    protected function getExpectedCommand(): string
    {
        return TOPKINCRBY::class;
    }

    /**
     * {@inheritDoc}
     */
    protected function getExpectedId(): string
    {
        return 'TOPKINCRBY';
    }

    /**
     * @group disconnected
     */
    public function testFilterArguments(): void
    {
        $actualArguments = ['key', 'item1', 1, 'item2', 2];
        $expectedArguments = ['key', 'item1', 1, 'item2', 2];

        $command = $this->getCommand();
        $command->setArguments($actualArguments);

        $this->assertSameValues($expectedArguments, $command->getArguments());
    }

    /**
     * @group disconnected
     */
    public function testParseResponse(): void
    {
        $this->assertSame(1, $this->getCommand()->parseResponse(1));
    }

    /**
     * @group connected
     * @group relay-resp3
     * @return void
     * @requiresRedisBfVersion >= 2.0.0
     */
    public function testIncrementItemsScoreOnGivenAmount(): void
    {
        $redis = $this->getClient();

        $redis->topkreserve('key', 2);
        $this->assertSame([null, null], $redis->topkadd('key', 'item1', 'item2'));

        $actualResponse = $redis->topkincrby('key', 'item1', 1, 'item2', 2, 'item3', 3);

        $this->assertEquals([null, null, 'item1'], $actualResponse);
        $this->assertEquals(['item2' => 3, 'item3' => 3], $redis->topklist('key', true));
    }

    /**
     * @group connected
     * @return void
     * @requiresRedisBfVersion >= 2.0.0
     */
    public function testThrowsExceptionOnNonExistingKey(): void
    {
        $redis = $this->getClient();

        $this->expectException(ServerException::class);
        $this->expectExceptionMessage('TopK: key does not exist');

        $redis->topkincrby('key', 'item', 1);
    }
}

==> php-nrk-predis_3.0.1.orig.tar.xz: php-nrk-predis-3.0.1/tests/Predis/Command/Redis/TopK/TOPKINCRBY_Test.php <==
<?php

/*
 * This file is part of the Predis package.
 *
 * (c) 2009-2020 Daniele Alessandri
 * (c) 2021-2025 Till Krüss
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Predis\Command\Redis\TopK;

use Predis\Command\Redis\PredisCommandTestCase;
use Predis\Response\ServerException;

/**
 * @group commands
 * @group realm-stack
 */
class TOPKINCRBY_Test extends PredisCommandTestCase
{
    /**
     * {@inheritDoc}
     */
    protected function getExpectedCommand(): string
    {
        return TOPKINCRBY::class;
    }

    /**
     * {@inheritDoc}
     */
    protected function getExpectedId(): string
    {
        return 'TOPKINCRBY';
    }

    /**
     * @group disconnected
     */
    public function testFilterArguments(): void
    {
        $actualArguments = ['key', 'item1', 1, 'item2', 2];
        $expectedArguments = ['key', 'item1', 1, 'item2', 2];

        $command = $this->getCommand();
        $command->setArguments($actualArguments);

        $this->assertSameValues($expectedArguments, $command->getArguments());
    }

    /**
     * @group disconnected
     */
    public function testParseResponse(): void
    {
        $this->assertSame(1, $this->getCommand()->parseResponse(1));
    }

    /**
     * @group connected
     * @group relay-resp3
     * @return void
     * @requiresRedisBfVersion >= 2.0.0
     */
    public function testIncrementItemsScoreOnGivenAmount(): void
    {
        $redis = $this->getClient();

        $redis->topkreserve('key', 2);
        $this->assertSame([null, null], $redis->topkadd('key', 'item1', 'item2'));

        $actualResponse = $redis->topkincrby('key', 'item1', 1, 'item2', 2, 'item3', 3);

        $this->assertEquals([null, null, 'item1'], $actualResponse);
        $this->assertEquals(['item2' => 3, 'item3' => 3], $redis->topklist('key', true));
    }

    /**
     * @group connected
     * @return void
     * @requiresRedisBfVersion >= 2.6.0
     */
    public function testIncrementItemsScoreOnGivenAmountResp3(): void
    {
        $redis = $this->getResp3Client();

        $redis->topkreserve('key', 2);
        $this->assertSame([null, null], $redis->topkadd('key', 'item1', 'item2'));

        $actualResponse = $redis->topkincrby('key', 'item1', 1, 'item2', 2, 'item3', 3);

        $this->assertEquals([null, null, 'item1'], $actualResponse);
        $this->assertEquals(['item2' => 3, 'item3' => 3], $redis->topklist('key', true));
    }

    /**
     * @group connected
     * @group relay-resp3
     * @return void
     * @requiresRedisBfVersion >= 2.0.0
     */
    public function testThrowsExceptionOnNonExistingKey(): void
    {
        $redis = $this->getClient();

        $this->expectException(ServerException::class);
        $this->expectExceptionMessage('TopK: key does not exist');

        $redis->topkincrby('key', 'item', 1);
    }
}
